const API_URL = 'https://api.themoviedb.org/3/search/movie';
const API_KEY = 'YOUR_TMDB_API_KEY'; // Replace with your actual API key

const form = document.getElementById('search-form');
const searchInput = document.getElementById('search-input');
const resultsContainer = document.getElementById('results');
const loading = document.getElementById('loading');
const errorContainer = document.getElementById('error');

form.addEventListener('submit', async (e) => {
  e.preventDefault();
  const query = searchInput.value.trim();
  
  if (!query) {
    errorContainer.textContent = 'Please enter a search term';
    errorContainer.classList.remove('hidden');
    return;
  }

  try {
    loading.classList.remove('hidden');
    errorContainer.classList.add('hidden');
    resultsContainer.innerHTML = '';
    
    const response = await fetch(`${API_URL}?api_key=${API_KEY}&query=${encodeURIComponent(query)}`);
    const data = await response.json();
    
    if (data.results.length === 0) {
      errorContainer.textContent = 'No movies found';
      errorContainer.classList.remove('hidden');
      return;
    }
    
    displayResults(data.results);
  } catch (err) {
    errorContainer.textContent = 'An error occurred while fetching data';
    errorContainer.classList.remove('hidden');
  } finally {
    loading.classList.add('hidden');
  }
});

function displayResults(movies) {
  resultsContainer.innerHTML = movies.map(movie => `
    <div class="movie-card">
      <img src="https://image.tmdb.org/t/p/w500${movie.poster_path}" alt="${movie.title}">
      <div class="movie-info">
        <h3>${movie.title}</h3>
        <p>${movie.overview.substring(0, 100)}...</p>
        <p>Rating: ${movie.vote_average}</p>
        <p>Release: ${movie.release_date}</p>
      </div>
    </div>
  `).join('');
}